__author__ = "Pavel Polyakov"
__copyright__ = "Copyright (C) 2016 Pavel Polyakov"
__version__ = "0.4"

import re
import time
from models import Port
from functions import getSnmp, parseTrap

class Processor(object):
    def work(self, data):
        trap = parseTrap(data)
        oid = trap.get('snmpTrapOID.0', None)
	if oid in ['IF-MIB::linkUp','IF-MIB::linkDown']:
            processor = PortProcessor()
            return processor.job(trap)
        else:
            return None

def find_state(message):
    try:
        return re.search('(up|down)',message,re.IGNORECASE).group().lower()
    except AttributeError:
        return None

class PortProcessor(object):

    def job(self, trap):
        host = trap['host']
        hostname = getSnmp(host, 'SNMPv2-MIB::sysName.0')
        event = trap['snmpTrapOID.0']
        ifIndex = trap.get('ifIndex')
        ifName = trap.get('ifName', getSnmp(host,'IF-MIB::ifName.'+ifIndex))
        ifAlias = trap.get('ifAlias', getSnmp(host,'IF-MIB::ifAlias.'+ifIndex))

        ifAdminStatus = trap.get('ifAdminStatus', getSnmp(host,'IF-MIB::ifAdminStatus.'+ifIndex))
        ifAdminStatus = find_state(ifAdminStatus)
        ifOperStatus = trap.get('ifOperStatus', getSnmp(host,'IF-MIB::ifOperStatus.'+ifIndex))
        ifOperStatus = find_state(ifOperStatus)
        if ifAdminStatus or ifOperStatus:
            return Port(
                    host = host,
                    hostname = hostname,
                    event = event,
                    ifIndex = ifIndex,
                    ifName = ifName,
                    ifAlias = ifAlias,
                    ifAdminStatus = ifAdminStatus,
                    ifOperStatus = ifOperStatus)
        else:
            return None
